/*
  The code in this file is licensed under Public Domain.
  The license can be found at http://creativecommons.org/licenses/publicdomain/.
  */

#ifndef ACCOUNTCLASS_H
#define ACCOUNTCLASS_H

#include "RuleClass.h"

#include <QString>
#include <QDate>
#include <QHash>
#include <QVector>

enum AccountType
{
    ACCOUNT_TYPE_INCOME,
    ACCOUNT_TYPE_EXPENSE,
    ACCOUNT_TYPE_TOTAL_INCOME,
    ACCOUNT_TYPE_TOTAL_EXPENSE,
    ACCOUNT_TYPE_HEADER
};

class AccountClass
{
public:
    AccountClass(AccountType type, QString guid, QDate oldestMonth, QDate selectedMonth);
    AccountType getType(void);
    QString getGuid();
    float GetMonthlyTotal(QDate date);
    RuleClass* GetMonthlyRule(QDate date);
    QString getName(void);

    bool getIsCalculated(QDate date);
    void setIsCalculated(bool isCalculated, QDate date);

    float getCalculatedPlanned(QDate date);
    float getCalculatedAccumulated(QDate date);

    void setCalculatedPlanned(float planned, QDate date);
    void setCalculatedAccumulated(float accumulated, QDate date);

    void setTotalAccountTotal(float total, QDate date);
    void setTotalAccountExtra(float extra, QDate date);
    float getTotalAccountTotal(QDate date);
    float getTotalAccountExtra(QDate date);

private:
    AccountType type;

    QVector<float> totalPlanned;
    QVector<float> totalAccumulated;
    QVector<bool> isCalculated;

    QString GetParentName(QString parent_guid);
    QString guid;
    QDate oldestMonth, selectedMonth;
    QString accountName;

    QHash<long, float> monthlyTotals;
    QHash<long, RuleClass*> monthlyRules;

    int DateToIndex(QDate date);
};

#endif // ACCOUNTCLASS_H
