/*
  The code in this file is licensed under Public Domain.
  The license can be found at http://creativecommons.org/licenses/publicdomain/.
  */

#ifndef BUDGETCLASS_H
#define BUDGETCLASS_H

#include <QStringList>
#include <QString>
#include <QDate>
#include <QHash>
#include "AccountClass.h"

#define TOTAL_INCOME "INCOME"
#define TOTAL_EXPENSE "EXPENSE"

class BudgetClass
{
public:
    BudgetClass(QDate debugCurrentMonth);
    void ComputeMonthlyTotal(QString guid, QDate month, float &expenses, float &planned, float &accumulated);
    RuleClass* GetRule(QString guid, QDate month);
    AccountClass *getAccount(QString guid) const;
    int rowCount(void);
    int columnCount(void);
    QString getGuid(int row);
    QDate columnToDate(int column) const;
    QString rowName(int row);

private:
    bool CreateDatabaseConnection(void);
    void ComputeBudget(QDate month);

    AccountClass *pHeader;
    AccountClass *pTotalIncome;
    AccountClass *pTotalExpenses;

    bool databaseOpen;
    QDate oldestMonth, selectedMonth;
    QHash<QString, AccountClass*> incomeAccounts;
    QHash<QString, AccountClass*> expenseAccounts;
    QStringList rowMapping;
};

#endif // BUDGETCLASS_H
