/*
  The code in this file is licensed under Public Domain.
  The license can be found at http://creativecommons.org/licenses/publicdomain/.
  */

#include "LogClass.h"

#include "Logger.h"

#include <iostream>
#include <iomanip>

LogClass::LogClass()
{
    // Specify the individual domain and logging level
    requestedDomains[QString("AccountClass")] = LOG_INFO;
    //requestedDomains[QString("AccountClass/get")] = LOG_INFO;
    requestedDomains[QString("BudgetClass/request")] = LOG_WARN;
    requestedDomains[QString("BudgetClass/rule")] = LOG_INFO;
    requestedDomains[QString("BudgetClass/compute")] = LOG_DEBUG;
    //requestedDomains[QString("BudgetClass")] = LOG_DEBUG;
    requestedDomains[QString("BudgetClass")] = LOG_INFO;
    debugRootDomain = true;
    startTime.start();
}

void LogClass::LogStr(QString domain,
                      int level,
                      QString str,
                      const char *pFunction,
                      const char *pFile,
                      int line)
{
    if(printDomain(domain,level) == true)
    {
        int milliseconds = startTime.elapsed();

        // Time - Domain - Output
        std::cerr << "Time:" << milliseconds / 1000 << "." << (milliseconds % 1000)
                << "  Domain:" << std::left << std::setw(25) << qPrintable(domain)
                << " - " << std::setw(50) << qPrintable(str)
                << " " << pFunction << "()-" << pFile << ":" << line << std::endl;
    }
}

bool LogClass::printDomain(QString domain, int level)
{
    //std::cerr << "Looking for domain:" << qPrintable(domain) << " and level:" << level << std::endl;
    if(domain == QString() || domain == QString("/"))
        return debugRootDomain;

    if(requestedDomains.contains(domain) == true)
    {
        //std::cerr << "Contains domain:" << qPrintable(domain) << std::endl;
        if(requestedDomains.value(domain) >= level)
        {
            return true;
        }
        else
        {
            return false;
        }
    }

    //std::cerr << "Doesn't contains domain:" << qPrintable(domain) << std::endl;
    int indexLast = domain.lastIndexOf(QString("/"));
    if(indexLast == -1)
        return debugRootDomain;

    return printDomain(domain.left(indexLast), level);

}
